@@ -60,7 +60,8 @@ define ([
         //
         miniMenu = function (mm) {
             // mm is the dbrowser miniMenu object
-            var len = mm.entries.length,
+            var entries = (mm.entries === null) ? [] : mm.entries,
+                len = entries.length,
                 entry,
                 i,
                 r;
@@ -70,8 +71,8 @@ define ([
                 r = 'Menu:&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;';
                 for (i = 0; i < len; i += 1) {
                     //console.log("i === " + i);
-                    console.log("Attempting to pull target " + mm.entries[i] + " from miniMenu");
-                    entry = target.pull(mm.entries[i]);
+                    console.log("Attempting to pull target " + entries[i] + " from miniMenu");
+                    entry = target.pull(entries[i]);
                     if (lib.privCheck(entry.aclProfile)) {
                         r += i + '. ' + entry.menuText + '&nbsp;&nbsp;';
                     }
@@ -413,6 +414,8 @@ define ([
                     column,
                     row,
                     col,
+                    headingsentry = {},
+                    superset,
                     maxl = [];
 
                 r += '<br><b>' + dto.title + '</b><br><br>';
@@ -422,10 +425,15 @@ define ([
                 }
 
                 // populate maxl array
+                dto.entries.map(function (e) {
+                    headingsentry[e.prop] = e.text;
+                })
+                superset = set.concat([headingsentry]);
+                console.log("superset", superset);
                 for (column = 0; column < dto.entries.length; column += 1) {
                     console.log("Column " + column);
                     entry = dto.entries[column];
-                    var elems = set.map(function (obj) {
+                    var elems = superset.map(function (obj) {
                         return obj[entry.prop];
                     });
                     var elemlengths = elems.map(function (elem) {
